stravalib.util.limiter.RateLimitRule
====================================

.. currentmodule:: stravalib.util.limiter

.. autoclass:: RateLimitRule


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~RateLimitRule.__init__
